.. meta::
    :google-site-verification:
        2AAgZNptPaMHxDeXJegA8i8aW1jURVBpQseacnHQr8Q

.. meta::
    :description:
        Repository of cryptography-related data available under a free license.

.. meta::
    :keywords:
        cryptodatahub,cryptography,cryptographic algorithms,tls cipher suites,ssl cipher kinds,client capabilities,
        ct logs, diffie-hellman parameters

.. meta::
    :author:
        Szilárd Pfeiffer

=======
Summary
=======

.. include:: ../README.rst

=======
Details
=======

.. toctree::
    :maxdepth: 3

    features

=======
History
=======

.. toctree::
    :maxdepth: 2

    changelog
